@@ -1,6 +1,6 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
 /*
- *  Copyright (C) 2002-2018  Ruby-GNOME2 Project Team
+ *  Copyright (C) 2002-2019  Ruby-GNOME Project Team
  *  Copyright (C) 2002,2003  Masahiro Sakai
  *
  *  This library is free software; you can redistribute it and/or
@@ -27,16 +27,13 @@
 #include "rbglibdeprecated.h"
 #include "rbglib2conversions.h"
 
-#ifndef __RBGLIB_H__
-#define __RBGLIB_H__
+#pragma once
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 #define RBGLIB_MAJOR_VERSION 3
-#define RBGLIB_MINOR_VERSION 2
-#define RBGLIB_MICRO_VERSION 3
+#define RBGLIB_MINOR_VERSION 4
+#define RBGLIB_MICRO_VERSION 2
 
 #ifndef RB_ZALLOC
 #  ifdef ZALLOC
@@ -46,6 +43,10 @@ extern "C" {
 #  endif
 #endif
 
+#ifndef RB_ALLOC
+#  define RB_ALLOC(type) ALLOC(type)
+#endif
+
 #ifndef RB_ALLOC_N
 #  define RB_ALLOC_N(type, n) ALLOC_N(type, n)
 #endif
@@ -151,7 +152,7 @@ extern "C" {
 #define G_DEF_ERROR2(domain, name, module, parent) \
     rbgerr_define_gerror(domain, name, module, parent, G_TYPE_INVALID)
 
-#if defined(G_PLATFORM_WIN32) && !defined(RUBY_GLIB2_STATIC_COMPILATION)
+#ifdef G_PLATFORM_WIN32
 #  ifdef RUBY_GLIB2_COMPILATION
 #    define RUBY_GLIB2_VAR __declspec(dllexport)
 #  else
@@ -191,10 +192,12 @@ VALUE rbg_filename_to_ruby(const gchar *filename);
 extern VALUE rbg_filename_to_ruby_free(gchar *filename);
 extern gchar *rbg_filename_from_ruby(VALUE filename);
 
-const gchar **rbg_rval2strv(volatile VALUE *value, long *n);
-const gchar **rbg_rval2strv_accept_nil(volatile VALUE *value, long *n);
+gchar **rbg_rval2strv(volatile VALUE *value, long *n);
+gchar **rbg_rval2strv_accept_nil(volatile VALUE *value, long *n);
 gchar **rbg_rval2strv_dup(volatile VALUE *value, long *n);
 gchar **rbg_rval2strv_dup_accept_nil(volatile VALUE *value, long *n);
+gchar **rbg_rval2filenamev(volatile VALUE *value, long *n);
+gchar **rbg_rval2filenamev_accept_nil(volatile VALUE *value, long *n);
 VALUE rbg_strv2rval(const gchar **strings);
 VALUE rbg_strv2rval_free(gchar **strings);
 
@@ -228,9 +231,15 @@ extern guint64 rbglib_num_to_uint64(VALUE val);
 extern VALUE rbg_variant_to_ruby(GVariant *variant);
 extern GVariant *rbg_variant_from_ruby(VALUE rb_variant);
 
+extern GVariantType *rbg_variant_type_from_ruby(VALUE rb_variant_type);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+extern void rbg_gc_guard(gpointer key, VALUE rb_object);
+extern void rbg_gc_unguard(gpointer key);
 
-#endif /* __RBGLIB_H__ */
+
+/* predicates */
+extern gboolean rbg_is_bytes(VALUE object);
+extern gboolean rbg_is_object(VALUE object);
+extern gboolean rbg_is_value(VALUE object);
+
+G_END_DECLS
